@@ -1,6 +1,8 @@
 # flake8: NOQA: E501
 """Sphinx documentation configuration for tmuxp."""
 
+from __future__ import annotations
+
 import contextlib
 import inspect
 import pathlib
@@ -22,7 +24,7 @@ sys.path.insert(0, str(src_root))
 sys.path.insert(0, str(cwd / "_ext"))
 
 # package data
-about: t.Dict[str, str] = {}
+about: dict[str, str] = {}
 with (src_root / "tmuxp" / "__about__.py").open() as fp:
     exec(fp.read(), about)
 
@@ -60,8 +62,8 @@ master_doc = "index"
 project = about["__title__"]
 project_copyright = about["__copyright__"]
 
-version = "%s" % (".".join(about["__version__"].split("."))[:2])
-release = "%s" % (about["__version__"])
+version = "{}".format(".".join(about["__version__"].split("."))[:2])
+release = "{}".format(about["__version__"])
 
 exclude_patterns = ["_build"]
 
@@ -73,8 +75,8 @@ html_extra_path = ["manifest.json"]
 html_static_path = ["_static"]
 html_favicon = "_static/favicon.ico"
 html_theme = "furo"
-html_theme_path: t.List[str] = []
-html_theme_options: t.Dict[str, t.Union[str, t.List[t.Dict[str, str]]]] = {
+html_theme_path: list[str] = []
+html_theme_options: dict[str, str | list[dict[str, str]]] = {
     "light_logo": "img/tmuxp.svg",
     "dark_logo": "img/tmuxp.svg",
     "footer_icons": [
@@ -143,7 +145,7 @@ intersphinx_mapping = {
 }
 
 
-def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
+def linkcode_resolve(domain: str, info: dict[str, str]) -> None | str:
     """
     Determine the URL corresponding to Python object.
 
@@ -191,7 +193,7 @@ def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
     except Exception:
         lineno = None
 
-    linespec = "#L%d-L%d" % (lineno, lineno + len(source) - 1) if lineno else ""
+    linespec = f"#L{lineno}-L{lineno + len(source) - 1}" if lineno else ""
 
     fn = relpath(fn, start=pathlib.Path(tmuxp.__file__).parent)
 
@@ -213,7 +215,7 @@ def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
     )
 
 
-def remove_tabs_js(app: "Sphinx", exc: Exception) -> None:
+def remove_tabs_js(app: Sphinx, exc: Exception) -> None:
     """Fix for sphinx-inline-tabs#18."""
     if app.builder.format == "html" and not exc:
         tabs_js = pathlib.Path(app.builder.outdir) / "_static" / "tabs.js"
@@ -221,6 +223,6 @@ def remove_tabs_js(app: "Sphinx", exc: Exception) -> None:
             tabs_js.unlink()  # When python 3.7 deprecated, use missing_ok=True
 
 
-def setup(app: "Sphinx") -> None:
+def setup(app: Sphinx) -> None:
     """Sphinx setup hook."""
     app.connect("build-finished", remove_tabs_js)
