@@ -1,9 +1,7 @@
-"""Command line tool for managing tmuxp workspaces.
+"""CLI for ``tmuxp load`` subcommand."""
 
-tmuxp.cli.load
-~~~~~~~~~~~~~~
+from __future__ import annotations
 
-"""
 import argparse
 import importlib
 import logging
@@ -13,138 +11,97 @@ import shutil
 import sys
 import typing as t
 
-from libtmux.common import has_gte_version
 from libtmux.server import Server
-from libtmux.session import Session
-from tmuxp.types import StrPath
 
-from .. import config_reader, exc, log, util
-from ..workspace import loader
-from ..workspace.builder import WorkspaceBuilder
-from ..workspace.finders import find_workspace_file, get_workspace_dir
+from tmuxp import exc, log, util
+from tmuxp._internal import config_reader
+from tmuxp.workspace import loader
+from tmuxp.workspace.builder import WorkspaceBuilder
+from tmuxp.workspace.finders import find_workspace_file, get_workspace_dir
+
 from .utils import prompt_choices, prompt_yes_no, style, tmuxp_echo
 
 if t.TYPE_CHECKING:
-    from typing_extensions import Literal, NotRequired, TypeAlias, TypedDict
+    from typing import TypeAlias
 
-    CLIColorsLiteral: TypeAlias = Literal[56, 88]
+    from libtmux.session import Session
+    from typing_extensions import NotRequired, TypedDict
+
+    from tmuxp.types import StrPath
+
+    CLIColorsLiteral: TypeAlias = t.Literal[56, 88]
 
     class OptionOverrides(TypedDict):
+        """Optional argument overrides for tmuxp load."""
+
         detached: NotRequired[bool]
-        new_session_name: NotRequired[t.Optional[str]]
+        new_session_name: NotRequired[str | None]
 
 
 class CLILoadNamespace(argparse.Namespace):
-    workspace_files: t.List[str]
-    socket_name: t.Optional[str]
-    socket_path: t.Optional[str]
-    tmux_config_file: t.Optional[str]
-    new_session_name: t.Optional[str]
-    answer_yes: t.Optional[bool]
-    append: t.Optional[bool]
-    colors: t.Optional["CLIColorsLiteral"]
-    log_file: t.Optional[str]
+    """Typed :class:`argparse.Namespace` for tmuxp load command."""
+
+    workspace_files: list[str]
+    socket_name: str | None
+    socket_path: str | None
+    tmux_config_file: str | None
+    new_session_name: str | None
+    answer_yes: bool | None
+    append: bool | None
+    colors: CLIColorsLiteral | None
+    log_file: str | None
 
 
-def set_layout_hook(session: Session, hook_name: str) -> None:
-    """Set layout hooks to normalize layout.
-
-    References:
-
-        - tmuxp issue: https://github.com/tmux-python/tmuxp/issues/309
-        - tmux issue: https://github.com/tmux/tmux/issues/1106
-
-    tmux 2.6+ requires that the window be viewed with the client before
-    select-layout adjustments can take effect.
-
-    To handle this, this function creates temporary hook for this session to
-    iterate through all windows and select the layout.
-
-    In order for layout changes to take effect, a client must at the very
-    least be attached to the window (not just the session).
-
-    hook_name is provided to allow this to set to multiple scenarios, such
-    as 'client-attached' (which the user attaches the session). You may
-    also want 'after-switch-client' for cases where the user loads tmuxp
-    sessions inside tmux since tmuxp offers to switch for them.
-
-    Also, the hooks are set immediately unbind after they're invoked via -u.
-
-    Parameters
-    ----------
-    session : :class:`libtmux.session.Session`
-        session to bind hook to
-    hook_name : str
-        hook name to bind to, e.g. 'client-attached'
-    """
-    cmd = ["set-hook", "-t", session.id, hook_name]
-    hook_cmd = []
-    attached_window = session.attached_window
-    for window in session.windows:
-        # unfortunately, select-layout won't work unless
-        # we've literally selected the window at least once
-        # with the client
-        hook_cmd.append(f"selectw -t {window.id}")
-        # edit: removed -t, or else it won't respect main-pane-w/h
-        hook_cmd.append("selectl")
-        hook_cmd.append("selectw -p")
-
-    # unset the hook immediately after executing
-    hook_cmd.append(
-        "set-hook -u -t {target_session} {hook_name}".format(
-            target_session=session.id, hook_name=hook_name
-        )
-    )
-    hook_cmd.append(f"selectw -t {attached_window.id}")
-
-    # join the hook's commands with semicolons
-    _hook_cmd = "{}".format("; ".join(hook_cmd))
-
-    # append the hook command
-    cmd.append(_hook_cmd)
-
-    # create the hook
-    session.cmd(*cmd)
-
-
-def load_plugins(sconf: t.Dict[str, t.Any]) -> t.List[t.Any]:
-    """
-    Load and return plugins in workspace
-    """
+def load_plugins(session_config: dict[str, t.Any]) -> list[t.Any]:
+    """Load and return plugins in workspace."""
     plugins = []
-    if "plugins" in sconf:
-        for plugin in sconf["plugins"]:
+    if "plugins" in session_config:
+        for plugin in session_config["plugins"]:
             try:
                 module_name = plugin.split(".")
                 module_name = ".".join(module_name[:-1])
                 plugin_name = plugin.split(".")[-1]
+            except Exception as error:
+                tmuxp_echo(
+                    style("[Plugin Error] ", fg="red")
+                    + f"Couldn't load {plugin}\n"
+                    + style(f"{error}", fg="yellow"),
+                )
+                sys.exit(1)
+
+            try:
                 plugin = getattr(importlib.import_module(module_name), plugin_name)
                 plugins.append(plugin())
             except exc.TmuxpPluginException as error:
                 if not prompt_yes_no(
-                    "%sSkip loading %s?"
-                    % (style(str(error), fg="yellow"), plugin_name),
+                    "{}Skip loading {}?".format(
+                        style(
+                            str(error),
+                            fg="yellow",
+                        ),
+                        plugin_name,
+                    ),
                     default=True,
                 ):
                     tmuxp_echo(
                         style("[Not Skipping] ", fg="yellow")
-                        + "Plugin versions constraint not met. Exiting..."
+                        + "Plugin versions constraint not met. Exiting...",
                     )
                     sys.exit(1)
             except Exception as error:
                 tmuxp_echo(
                     style("[Plugin Error] ", fg="red")
                     + f"Couldn't load {plugin}\n"
-                    + style(f"{error}", fg="yellow")
+                    + style(f"{error}", fg="yellow"),
                 )
                 sys.exit(1)
 
     return plugins
 
 
-def _reattach(builder: WorkspaceBuilder):
+def _reattach(builder: WorkspaceBuilder) -> None:
     """
-    Reattach session (depending on env being inside tmux already or not)
+    Reattach session (depending on env being inside tmux already or not).
 
     Parameters
     ----------
@@ -163,7 +120,7 @@ def _reattach(builder: WorkspaceBuilder):
         plugin.reattach(builder.session)
         proc = builder.session.cmd("display-message", "-p", "'#S'")
         for line in proc.stdout:
-            print(line)
+            print(line)  # NOQA: T201 RUF100
 
     if "TMUX" in os.environ:
         builder.session.switch_client()
@@ -174,7 +131,7 @@ def _reattach(builder: WorkspaceBuilder):
 
 def _load_attached(builder: WorkspaceBuilder, detached: bool) -> None:
     """
-    Load workspace in new session
+    Load workspace in new session.
 
     Parameters
     ----------
@@ -188,27 +145,16 @@ def _load_attached(builder: WorkspaceBuilder, detached: bool) -> None:
         # unset TMUX, save it, e.g. '/tmp/tmux-1000/default,30668,0'
         tmux_env = os.environ.pop("TMUX")
 
-        if has_gte_version("2.6"):
-            set_layout_hook(builder.session, "client-session-changed")
-
         builder.session.switch_client()  # switch client to new session
 
         os.environ["TMUX"] = tmux_env  # set TMUX back again
-    else:
-        if has_gte_version("2.6"):
-            # if attaching for first time
-            set_layout_hook(builder.session, "client-attached")
-
-            # for cases where user switches client for first time
-            set_layout_hook(builder.session, "client-session-changed")
-
-        if not detached:
-            builder.session.attach_session()
+    elif not detached:
+        builder.session.attach_session()
 
 
 def _load_detached(builder: WorkspaceBuilder) -> None:
     """
-    Load workspace in new session but don't attach
+    Load workspace in new session but don't attach.
 
     Parameters
     ----------
@@ -218,16 +164,12 @@ def _load_detached(builder: WorkspaceBuilder) -> None:
 
     assert builder.session is not None
 
-    if has_gte_version("2.6"):  # prepare for both cases
-        set_layout_hook(builder.session, "client-attached")
-        set_layout_hook(builder.session, "client-session-changed")
-
-    print("Session created in detached state.")
+    print("Session created in detached state.")  # NOQA: T201 RUF100
 
 
 def _load_append_windows_to_current_session(builder: WorkspaceBuilder) -> None:
     """
-    Load workspace as new windows in current session
+    Load workspace as new windows in current session.
 
     Parameters
     ----------
@@ -236,14 +178,10 @@ def _load_append_windows_to_current_session(builder: WorkspaceBuilder) -> None:
     current_attached_session = builder.find_current_attached_session()
     builder.build(current_attached_session, append=True)
     assert builder.session is not None
-    if has_gte_version("2.6"):  # prepare for both cases
-        set_layout_hook(builder.session, "client-attached")
-        set_layout_hook(builder.session, "client-session-changed")
 
 
 def _setup_plugins(builder: WorkspaceBuilder) -> Session:
-    """
-    Runs after before_script
+    """Execute hooks for plugins running after ``before_script``.
 
     Parameters
     ----------
@@ -258,17 +196,16 @@ def _setup_plugins(builder: WorkspaceBuilder) -> Session:
 
 def load_workspace(
     workspace_file: StrPath,
-    socket_name: t.Optional[str] = None,
+    socket_name: str | None = None,
     socket_path: None = None,
-    tmux_config_file: t.Optional[str] = None,
-    new_session_name: t.Optional[str] = None,
-    colors: t.Optional[int] = None,
+    tmux_config_file: str | None = None,
+    new_session_name: str | None = None,
+    colors: int | None = None,
     detached: bool = False,
     answer_yes: bool = False,
     append: bool = False,
-) -> t.Optional[Session]:
-    """
-    Load a tmux "workspace" session via tmuxp file.
+) -> Session | None:
+    """Entrypoint for ``tmuxp load``, load a tmuxp "workspace" session via config file.
 
     Parameters
     ----------
@@ -294,7 +231,6 @@ def load_workspace(
 
     Notes
     -----
-
     tmuxp will check and load a workspace file. The file will use ConfigReader
     to load a JSON/YAML into a :py:obj:`dict`. Then :func:`loader.expand` and
     :func:`loader.trickle` will be used to expand any shorthands, template
@@ -367,7 +303,7 @@ def load_workspace(
 
     tmuxp_echo(
         style("[Loading] ", fg="green")
-        + style(str(workspace_file), fg="blue", bold=True)
+        + style(str(workspace_file), fg="blue", bold=True),
     )
 
     # ConfigReader allows us to open a yaml or json file as a dict
@@ -375,7 +311,8 @@ def load_workspace(
 
     # shapes workspaces relative to config / profile file location
     expanded_workspace = loader.expand(
-        raw_workspace, cwd=os.path.dirname(workspace_file)
+        raw_workspace,
+        cwd=os.path.dirname(workspace_file),
     )
 
     # Overridden session name
@@ -396,10 +333,12 @@ def load_workspace(
 
     try:  # load WorkspaceBuilder object for tmuxp workspace / tmux server
         builder = WorkspaceBuilder(
-            sconf=expanded_workspace, plugins=load_plugins(expanded_workspace), server=t
+            session_config=expanded_workspace,
+            plugins=load_plugins(expanded_workspace),
+            server=t,
         )
     except exc.EmptyWorkspaceException:
-        tmuxp_echo("%s is empty or parsed no workspace data" % workspace_file)
+        tmuxp_echo(f"{workspace_file} is empty or parsed no workspace data")
         return None
 
     session_name = expanded_workspace["session_name"]
@@ -409,7 +348,9 @@ def load_workspace(
         if not detached and (
             answer_yes
             or prompt_yes_no(
-                "%s is already running. Attach?" % style(session_name, fg="green"),
+                "{} is already running. Attach?".format(
+                    style(session_name, fg="green"),
+                ),
                 default=True,
             )
         ):
@@ -430,7 +371,7 @@ def load_workspace(
             return _setup_plugins(builder)
 
         # append and answer_yes have no meaning if specified together
-        elif answer_yes:
+        if answer_yes:
             _load_attached(builder, detached)
             return _setup_plugins(builder)
 
@@ -465,7 +406,7 @@ def load_workspace(
 
         if choice == "k":
             if builder.session is not None:
-                builder.session.kill_session()
+                builder.session.kill()
                 tmuxp_echo("Session killed.")
         elif choice == "a":
             _reattach(builder)
@@ -476,6 +417,7 @@ def load_workspace(
 
 
 def create_load_subparser(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
+    """Augment :class:`argparse.ArgumentParser` with ``load`` subcommand."""
     workspace_files = parser.add_argument(
         "workspace_files",
         nargs="+",
@@ -570,7 +512,7 @@ def create_load_subparser(parser: argparse.ArgumentParser) -> argparse.ArgumentP
 
 def command_load(
     args: CLILoadNamespace,
-    parser: t.Optional[argparse.ArgumentParser] = None,
+    parser: argparse.ArgumentParser | None = None,
 ) -> None:
     """Load a tmux workspace from each WORKSPACE_FILE.
 
@@ -627,7 +569,8 @@ def command_load(
 
     for idx, workspace_file in enumerate(args.workspace_files):
         workspace_file = find_workspace_file(
-            workspace_file, workspace_dir=get_workspace_dir()
+            workspace_file,
+            workspace_dir=get_workspace_dir(),
         )
 
         detached = original_detached_option
