@@ -16,7 +16,8 @@ from libtmux.common import has_gte_version, has_lt_version
 from libtmux.exc import LibTmuxException
 from libtmux.pane import Pane
 from libtmux.session import Session
-from libtmux.test import retry_until, temp_session
+from libtmux.test.retry import retry_until
+from libtmux.test.temporary import temp_session
 from libtmux.window import Window
 
 from tests.constants import EXAMPLE_PATH, FIXTURE_PATH
@@ -456,7 +457,7 @@ def test_environment_variables_warns_prior_to_tmux_3_0(
         sum(
             1
             for record in caplog.records
-            if "Cannot set environment for new windows." in record.msg
+            if "Cannot set environment for new windows." in record.message
         )
         # From window_overrides and both_overrides, but not
         # both_overrides_in_first_pane.
@@ -466,7 +467,7 @@ def test_environment_variables_warns_prior_to_tmux_3_0(
         sum(
             1
             for record in caplog.records
-            if "Cannot set environment for new panes." in record.msg
+            if "Cannot set environment for new panes." in record.message
         )
         # From pane_overrides and both_overrides, but not both_overrides_in_first_pane.
         == 2
@@ -475,7 +476,7 @@ def test_environment_variables_warns_prior_to_tmux_3_0(
         sum(
             1
             for record in caplog.records
-            if "Cannot set environment for new panes and windows." in record.msg
+            if "Cannot set environment for new panes and windows." in record.message
         )
         # From both_overrides_in_first_pane.
         == 1
@@ -585,7 +586,7 @@ def test_start_directory(session: Session, tmp_path: pathlib.Path) -> None:
     assert session == builder.session
     dirs = ["/usr/bin", "/dev", str(test_dir), "/usr", "/usr"]
 
-    for path, window in zip(dirs, session.windows):
+    for path, window in zip(dirs, session.windows, strict=False):
         for p in window.panes:
 
             def f(path: str, p: Pane) -> bool:
@@ -640,7 +641,7 @@ def test_start_directory_relative(session: Session, tmp_path: pathlib.Path) -> N
 
     dirs = ["/usr/bin", "/dev", str(test_dir), str(config_dir), str(config_dir)]
 
-    for path, window in zip(dirs, session.windows):
+    for path, window in zip(dirs, session.windows, strict=False):
         for p in window.panes:
 
             def f(path: str, p: Pane) -> bool:
@@ -717,7 +718,10 @@ def test_pane_order(session: Session) -> None:
 
     for w in session.windows:
         pane_base_index = w.show_window_option("pane-base-index", g=True)
+        assert pane_base_index is not None
+        pane_base_index = int(pane_base_index)
         for p_index, p in enumerate(w.panes, start=pane_base_index):
+            assert p.index is not None
             assert int(p_index) == int(p.index)
 
             # pane-base-index start at base-index, pane_paths always start
@@ -1426,7 +1430,7 @@ def test_first_pane_start_directory(session: Session, tmp_path: pathlib.Path) ->
 
     assert session.windows
     window = session.windows[0]
-    for path, p in zip(dirs, window.panes):
+    for path, p in zip(dirs, window.panes, strict=False):
 
         def f(path: str, p: Pane) -> bool:
             pane_path = p.pane_current_path
